Package: doris / 5.0.3~beta+dfsg-7

0001-spelling.patch Patch series | download
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
From: Debian GIS Project <pkg-grass-devel@lists.alioth.debian.org>
Date: Tue, 26 Nov 2013 09:08:12 +0000
Subject: spelling

Fix spelling errors
---
 doris_core/coregistration.cc | 14 +++++++-------
 doris_core/exceptions.cc     |  4 ++--
 doris_core/filtering.cc      |  2 +-
 doris_core/geocode.cc        |  2 +-
 doris_core/processor.cc      |  2 +-
 doris_core/readdata.cc       |  4 ++--
 doris_core/readinput.cc      | 32 ++++++++++++++++----------------
 sar_tools/cpxfiddle.cc       |  2 +-
 8 files changed, 31 insertions(+), 31 deletions(-)

diff --git a/doris_core/exceptions.cc b/doris_core/exceptions.cc
index 1855ca1..3c8905a 100755
--- a/doris_core/exceptions.cc
+++ b/doris_core/exceptions.cc
@@ -107,8 +107,8 @@ void handle_signal(int signum)
       break;
 #endif
     case SIGINT:
-      cout << "Caught SIGINT: User interupt signal." << endl;
-      cerr << "Caught SIGINT: User interupt signal." << endl;
+      cout << "Caught SIGINT: User interrupt signal." << endl;
+      cerr << "Caught SIGINT: User interrupt signal." << endl;
       exit(1);
       break;
     case SIGFPE:
diff --git a/doris_core/filtering.cc b/doris_core/filtering.cc
index 7cc2063..eb8fa83 100755
--- a/doris_core/filtering.cc
+++ b/doris_core/filtering.cc
@@ -2010,7 +2010,7 @@ void azimuthfilter(
     {
     INFO << "Variation of fDC for master and slave < " << max_fdc_change;
     INFO.print();
-    INFO.print("Reseting Doppler polynomial to constant of center crop:");
+    INFO.print("Resetting Doppler polynomial to constant of center crop:");
     master.f_DC_a0 = master_fdc_p05;
     master.f_DC_a1 = 0.0;
     master.f_DC_a2 = 0.0;
diff --git a/doris_core/geocode.cc b/doris_core/geocode.cc
index a32ef6f..8dbf1f8 100755
--- a/doris_core/geocode.cc
+++ b/doris_core/geocode.cc
@@ -362,7 +362,7 @@ void slant2hschwabisch(
          << 100*(buffer-1)/(FULLBUFFERS+EXTRABUFFER) << "%";
     PROGRESS.print();
 
-    // ______ In original master coordinate sytem ______
+    // ______ In original master coordinate system ______
     const real8 firstline = veryfirstline + (buffer-1) * bufferlines * multiL;
 
     // ______ Set indices for loading / check last buffer ______
diff --git a/doris_core/processor.cc b/doris_core/processor.cc
index 9ce084a..6badd70 100755
--- a/doris_core/processor.cc
+++ b/doris_core/processor.cc
@@ -3926,7 +3926,7 @@ void quote()
     "Beauty can be perceived but not explained.", // 130
     "Programming is like sex: one mistake and you have to\n\tsupport it for the rest of your life. [Michael Sinz]",
     "I wish you were here and I was there [me].",
-    "In mathematics you dont understand things, you just get used to them [Neumann].",
+    "In mathematics you don't understand things, you just get used to them [Neumann].",
     "A man is incomplete until he is married. After that, he is finished [Zsa Zsa Gabor].",
     "Unlikely children's book title:\n\t\"The Kids' Guide to Hitchhiking\".", // 138
     "Unlikely children's book title:\n\t\"Whining, Kicking and Crying to Get Your Way\".",
diff --git a/doris_core/readdata.cc b/doris_core/readdata.cc
index 00627d5..487d9da 100755
--- a/doris_core/readdata.cc
+++ b/doris_core/readdata.cc
@@ -1708,7 +1708,7 @@ else//RSAT method specified
   // to what (time) does the annotated GMHA refer?
   DEBUG << "GMHA [rad]: " << GMHA;
   DEBUG.print();
-  DEBUG << "Convertion from inertial to earth fixed [1/-1]: " << csi2cse;
+  DEBUG << "Conversion from inertial to earth fixed [1/-1]: " << csi2cse;
   DEBUG.print();
   DEBUG << "earthrot [rad/s]: " << earthrot;
   DEBUG.print();
@@ -2355,7 +2355,7 @@ if (readfiles_arg.sensor_id==SLC_RSAT && readfiles_arg.sar_processor==SARPR_ATL)
   scratchresfile
     << "Leader file:                                 \t"
     <<  readfiles_arg.leaderfile
-    << "\nSensor platform mission identifer:         \t"
+    << "\nSensor platform mission identifier:        \t"
     <<  c32sensorid
     << "\nScene_centre_latitude:                     \t"
     <<  c16centerlat
diff --git a/sar_tools/cpxfiddle.cc b/sar_tools/cpxfiddle.cc
index 3e44c25..97c7702 100644
--- a/sar_tools/cpxfiddle.cc
+++ b/sar_tools/cpxfiddle.cc
@@ -2256,7 +2256,7 @@ void usage(char *programname)
        << "\n   -M with -m:   First mirrored then multilooked."
        << "\n   -B:           Not tested properly, but simply calls functions."
        << "\n   all:          If cpxfile is a symbolic link, filesize cannot be"
-       << "\n                 determined, and therefor the number of lines."
+       << "\n                 determined, and therefore the number of lines."
        << "\n                 Solution: Use the full path or use a hard link."
        << "\n   (lot of options, binary to screen, but these are features.)"
diff --git a/doris_core/coregistration.cc b/doris_core/coregistration.cc
index c316cf6..fa59bc6 100644
--- a/doris_core/coregistration.cc
+++ b/doris_core/coregistration.cc
@@ -1363,7 +1363,7 @@ void mtiming_correl(
   int32 offsetLines  = -999; // NaN
   int32 offsetPixels = -999;
   //getoffset(Result,offsetLines,offsetPixels);   // getoffsets based on Mean
-  getmodeoffset(Result,offsetLines,offsetPixels); // [MA] max occurence
+  getmodeoffset(Result,offsetLines,offsetPixels); // [MA] max occurrence
 
 
   // ______ Convert offsets to seconds and write  master time offset to res file ______
@@ -1727,7 +1727,7 @@ void mtiming_correlfft(
   int32 offsetLines  = -999; // NaN
   int32 offsetPixels = -999;
   //getoffset(Result,offsetLines,offsetPixels);   // getoffsets based on Mean
-  getmodeoffset(Result,offsetLines,offsetPixels); // [MA] max occurence
+  getmodeoffset(Result,offsetLines,offsetPixels); // [MA] max occurrence
 
 
   // ______ Convert offsets to seconds and write master time offset to res file ______
@@ -2377,7 +2377,7 @@ cerr << endl;
                  << "\n* MTIMING_CORRELATION: Offset Frequency Table"
                  << "\n*******************************************************************"
                  << "\nUsing following data to determine coarse image offset:"
-                 << "\navg. coh    offset_L    offset_P  occurence  index"
+                 << "\navg. coh    offset_L    offset_P  occurrence  index"
                  << "\n------------------------------------------------------";  // TODO not yet: scratchlogfile << INFO
 
    // _____ Mode of offsets _____  [MA]
@@ -2385,7 +2385,7 @@ cerr << endl;
   PROGRESS << "Using as threshold:  " << thresh_coh << " and checking for mode value";
   PROGRESS.print();
   INFO.print("Using following data to determine coarse image offset:");
-  INFO.print("avg. coh    offset_L    offset_P  occurence  index");
+  INFO.print("avg. coh    offset_L    offset_P  occurrence  index");
   INFO.print("------------------------------------------------------");
 
   mysort231(sortResult);                        // re-sort on 2nd, 3rd than 1st column
@@ -2412,7 +2412,7 @@ cerr << endl;
          }
       offset_freq=0;   // reset
       offset_mcoh=0;
-      for (register uint j=0; j<nW; j++)           // scan data for occurences of an offset
+      for (register uint j=0; j<nW; j++)           // scan data for occurrences of an offset
         {                                          // for all offsets
          if ( L == int32(rint(sortResult(j,1))) && P == int32(rint(sortResult(j,2))) )
            {
@@ -2449,7 +2449,7 @@ cerr << endl;
     scratchlogfile << "\n\n*******************************************************************";
     scratchlogfile.close();  // close scratchlogmtiminghtr
 
     // _____ Even occurence check _____
     if (mode_val == evenmode_val) // there are even values of mode.
       {
         WARNING << "There are " << nEven << " offset pairs which has equal mode values are equal.";
@@ -2471,7 +2471,7 @@ cerr << endl;
     }
   if (mode_val == 1)
     {
-    WARNING.print("getmodeoffset: all the offset occurence == 1. There is no mode value. ");
+    WARNING.print("getmodeoffset: all the offset occurrence == 1. There is no mode value. ");
     WARNING.print("(please check bottom of LOGFILE to see if offset is OK or change window size.)");
     }
   if (nW < 6)
@@ -2449,7 +2449,7 @@ cerr << endl;
     scratchlogfile.close();  // close scratchlogmtiminghtr
 
-    // _____ Even occurence check _____
+    // _____ Even occurrence check _____
     if (mode_val == evenmode_val) // there are even values of mode.
       {
diff --git a/doris_core/readinput.cc b/doris_core/readinput.cc
index 2c45931..57d7c94 100755
--- a/doris_core/readinput.cc
+++ b/doris_core/readinput.cc
@@ -197,7 +197,7 @@ void readinput(
   //char                  filename[4*ONE27];            // string for filenames // [MA] changed EIGHTY --> 2*ONE27, due to comments line gets longer
   char                  eachline[4*ONE27];           // assuming maximum char lenght of the line is 4*ONE27. It should be sufficient.
 
   // ______ Check (multiple) occurence of cards ______
   bool                  priorscreen     = false;     // no screen card present
   bool                  priormemory     = false;     // check if present for info
   bool                  priorbatch      = false;     // check if present for info
@@ -747,7 +747,7 @@ void readinput(
         {
         case true:
           WARNING << "SCREEN: line " << linecnt << ": stdout: "
-               << " ignored due to prior occurence.";
+               << " ignored due to prior occurrence.";
           WARNING.print();
           break;
 
@@ -846,7 +846,7 @@ void readinput(
         {
         case true:
           WARNING << "MEMORY: line " << linecnt
-               << ": ignored due to prior occurence.";
+               << ": ignored due to prior occurrence.";
           WARNING.print();
           break;
 
@@ -879,11 +879,11 @@ void readinput(
         {
         case true:
           WARNING << "BATCH: line: " << linecnt << ": "
-               << "ignored due to prior occurence.";
+               << "ignored due to prior occurrence.";
           WARNING.print();
           break;
         default:
-          priorbatch = true;                            // flag for occurence
+          priorbatch = true;                            // flag for occurrence
          // keyword =  word[1] ;        // pass keyword                 // argument
           keyword = word[1];                  // pass next word       (the argument)
           writearg(keyword);
@@ -913,11 +913,11 @@ void readinput(
         {
         case true:
           WARNING << "OVERWRITE: line: " << linecnt << ": "
-               << "ignored due to prior occurence.";
+               << "ignored due to prior occurrence.";
           WARNING.print();
           break;
         default:
-          prioroverwrite = true;                                // flag for occurence
+          prioroverwrite = true;                                // flag for occurrence
           keyword = word[1];                  // pass next word       (the argument)
           writearg(keyword);
           toupper(keyword);
@@ -946,11 +946,11 @@ void readinput(
         {
         case true:
           WARNING << "LISTINPUT: line: " << linecnt << ": "
-               << "ignored due to prior occurence.";
+               << "ignored due to prior occurrence.";
           WARNING.print();
           break;
         default:
-          priorlistinput = true;                                // flag for occurence
+          priorlistinput = true;                                // flag for occurrence
           keyword = word[1];                  // pass next word       (the argument)
           writearg(keyword);
           toupper(keyword);
@@ -979,7 +979,7 @@ void readinput(
       //  the flag input array 'process[NUMPROCESSES]' after reading reset input
       //  to avoid interference with PROCESS cards (ONLYPROCESS overrides)
       //
-      if (onlyprocess == -1)                             // check multiple occurences
+      if (onlyprocess == -1)                             // check multiple occurrences
         {
           keyword = word[1];                  // pass next word       (the argument)
         writearg(keyword);
@@ -1079,7 +1079,7 @@ void readinput(
         }
       else
         {
-        WARNING << "ONLYPROCESS: more than one occurence of card, ignored line: "
+        WARNING << "ONLYPROCESS: more than one occurrence of card, ignored line: "
                    << linecnt << ".";
         WARNING.print();
 
@@ -1375,7 +1375,7 @@ void readinput(
       else if (!strcmp(keyword,"XV"))
         {
         generalinput.preview = 2;
-        INFO.print("PREVIEW: \tON: generation of SUNraster files enabled + XV sytem call.");
+        INFO.print("PREVIEW: \tON: generation of SUNraster files enabled + XV system call.");
         }
       else if (!strcmp(keyword,"ON")    ||
                !strncmp(keyword,"//",2) ||              // comment
@@ -1705,7 +1705,7 @@ void readinput(
     else if (!strcmp(keyword,"M_ORBDIR"))             // orbitfile filename
       {                                               
       if (specified(porbitsinput.m_orbdir))
-               WARNING.print("Prior occurence of M_ORBDIR ignored.");
+               WARNING.print("Prior occurrence of M_ORBDIR ignored.");
       strcpy(porbitsinput.m_orbdir,  word[1] );         // pass keyword
       writearg(porbitsinput.m_orbdir);
       }
@@ -1762,7 +1762,7 @@ void readinput(
     else if (!strcmp(keyword,"S_ORBDIR"))             // orbitfile filename
       {                                               
       if (specified(porbitsinput.s_orbdir))
-              WARNING.print("Prior occurence of S_ORBDIR ignored.");
+              WARNING.print("Prior occurrence of S_ORBDIR ignored.");
       strcpy(porbitsinput.s_orbdir,  word[1] );         // pass keyword
       writearg(porbitsinput.s_orbdir);
       }
@@ -3446,7 +3446,7 @@ void readinput(
         {
         case true:
           WARNING << "RS_OUT_FILE: line: " << linecnt << ": "
-              << "ignored due to prior occurence.";
+              << "ignored due to prior occurrence.";
           WARNING.print();
           break;
         default:
@@ -5785,7 +5785,7 @@ void checkunwrap(
 
     case uw_method2:
       INFO.print("Method 2: SNAPHU is used for unwrapping.");
-      INFO.print("Please make sure snaphu is installed.  check results carefuly.");
+      INFO.print("Please make sure snaphu is installed.  check results carefully.");
       INFO << "UW_SNAPHU_LOG: \tOutput log file of snaphu: "
            << unwrapinput.snaphu_log;
       INFO.print();
@@ -197,7 +197,7 @@ void readinput(
   char                  eachline[4*ONE27];           // assuming maximum char lenght of the line is 4*ONE27. It should be sufficient.
 
-  // ______ Check (multiple) occurence of cards ______
+  // ______ Check (multiple) occurrence of cards ______
   bool                  priorscreen     = false;     // no screen card present
   bool                  priormemory     = false;     // check if present for info